'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactBootstrap = require('react-bootstrap');

var _uuid = require('uuid');

var _uuid2 = _interopRequireDefault(_uuid);

var _translate = require('../../../translate');

var _translate2 = _interopRequireDefault(_translate);

var _Icon = require('../../../Icon');

var _Icon2 = _interopRequireDefault(_Icon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getIcon(selected) {
	switch (selected) {
		case 'table':
			return 'talend-table';
		case 'large':
			return 'talend-expanded';
		case 'tile':
			return 'talend-tiles';
		default:
			return 'talend-table';
	}
}

function getLabel(selected, t) {
	switch (selected) {
		case 'table':
			return t('LIST_SELECT_DISPLAY_MODE_TABLE', { defaultValue: 'Table' });
		case 'large':
			return t('LIST_SELECT_DISPLAY_MODE_LARGE', { defaultValue: 'Expanded' });
		case 'tile':
			return t('LIST_SELECT_DISPLAY_MODE_TILE', { defaultValue: 'Tile' });
		default:
			return t('LIST_SELECT_DISPLAY_MODE_TABLE', { defaultValue: 'Table' });
	}
}

var options = ['table', 'large', 'tile'];

function SelectDisplayMode(_ref) {
	var id = _ref.id,
	    mode = _ref.mode,
	    displayModes = _ref.displayModes,
	    onChange = _ref.onChange,
	    t = _ref.t;

	var selected = mode || 'table';
	var modes = displayModes || options;
	var displayIcon = _react2.default.createElement(_Icon2.default, { name: getIcon(selected) });

	function onChangeMode(value, event) {
		return onChange(event, value);
	}

	function getMenuItem(option) {
		return _react2.default.createElement(
			_reactBootstrap.MenuItem,
			{
				id: id && id + '-' + option,
				key: option,
				eventKey: option
			},
			_react2.default.createElement(_Icon2.default, { name: getIcon(option) }),
			getLabel(option, t)
		);
	}

	return _react2.default.createElement(
		_reactBootstrap.Nav,
		null,
		_react2.default.createElement(
			_reactBootstrap.NavDropdown,
			{
				id: id || _uuid2.default.v4(),
				title: displayIcon,
				onSelect: onChangeMode
			},
			modes.map(function (option) {
				return getMenuItem(option);
			})
		)
	);
}

SelectDisplayMode.propTypes = {
	id: _propTypes2.default.string,
	mode: _propTypes2.default.string,
	displayModes: _propTypes2.default.arrayOf(_propTypes2.default.string),
	onChange: _propTypes2.default.func.isRequired,
	t: _propTypes2.default.func.isRequired
};

SelectDisplayMode.defaultProps = {
	t: _translate2.default
};

exports.default = SelectDisplayMode;