'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _uuid = require('uuid');

var _uuid2 = _interopRequireDefault(_uuid);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactAutowhatever = require('react-autowhatever');

var _reactAutowhatever2 = _interopRequireDefault(_reactAutowhatever);

var _Typeahead = require('./Typeahead.scss');

var _Typeahead2 = _interopRequireDefault(_Typeahead);

var _TypeaheadComponent = require('./Typeahead.component.renderers');

var _Actions = require('../Actions');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Show suggestions for search bar
 * @example
 *
 * <Typeahead {...props} />
 */
function Typeahead(_ref) {
	var onToggle = _ref.onToggle,
	    icon = _ref.icon,
	    position = _ref.position,
	    rest = _objectWithoutProperties(_ref, ['onToggle', 'icon', 'position']);

	if (onToggle) {
		return _react2.default.createElement(_Actions.Action, {
			onClick: onToggle,
			label: icon.title,
			hideLabel: true,
			icon: icon.name,
			bsStyle: icon.bsStyle,
			className: _Typeahead2.default['only-icon-cls'],
			tooltipPlacement: icon.tooltipPlacement
		});
	}

	var sectionProps = rest.multiSection ? { getSectionItems: function getSectionItems(section) {
			return section.suggestions;
		}, renderSectionTitle: _TypeaheadComponent.renderSectionTitle } : null;

	var themeProps = {
		theme: _extends({
			containerOpen: _Typeahead2.default['container-open'],
			highlight: _Typeahead2.default['highlight-match'],
			input: _Typeahead2.default['typeahead-input'],
			itemFocused: _Typeahead2.default['item-focused'],
			itemsContainer: _Typeahead2.default['items-container'],
			itemsList: _Typeahead2.default.items,
			sectionContainer: _Typeahead2.default['section-container']

		}, rest.theme, {
			container: (0, _classnames2.default)(_Typeahead2.default['tc-typeahead-container'], position === 'right' && _Typeahead2.default.right, rest.theme && rest.theme.container, rest.className)
		})
	};

	var inputProps = {
		renderInputComponent: _TypeaheadComponent.renderInputComponent,
		inputProps: {
			autoFocus: rest.autoFocus,
			debounceMinLength: rest.debounceMinLength,
			debounceTimeout: rest.debounceTimeout,
			onBlur: rest.onBlur,
			onChange: rest.onChange && function (event) {
				return rest.onChange(event, { value: event.target.value });
			},
			onFocus: rest.onFocus,
			onKeyDown: rest.onKeyDown,
			placeholder: rest.placeholder,
			value: rest.value,
			icon: icon
		}
	};

	var defaultRenderersProps = {
		renderItem: _TypeaheadComponent.renderItem,
		renderItemsContainer: (0, _TypeaheadComponent.renderItemsContainerFactory)(rest.items, rest.noResultText, rest.searching, rest.searchingText),
		renderItemData: { value: rest.value }
	};

	var autowhateverProps = _extends({}, defaultRenderersProps, rest, sectionProps, themeProps, inputProps, {
		items: rest.items || [],
		itemProps: {
			onMouseDown: rest.onSelect
		}
	});

	return _react2.default.createElement(_reactAutowhatever2.default, autowhateverProps);
}

Typeahead.defaultProps = {
	id: _uuid2.default.v4(),
	position: 'left',
	items: null,
	autoFocus: true,
	multiSection: true, // TODO this is for compat, see if we can do the reverse :(
	noResultText: 'No result.',
	searching: false,
	searchingText: 'Searching for matches…'
};

Typeahead.propTypes = {
	// container
	id: _propTypes2.default.string,
	className: _propTypes2.default.string,
	noResultText: _propTypes2.default.string,
	position: _propTypes2.default.oneOf(['left', 'right']),
	searching: _propTypes2.default.bool,
	searchingText: _propTypes2.default.string,

	// toggle button
	onToggle: _propTypes2.default.func,
	icon: _propTypes2.default.shape({
		name: _propTypes2.default.string,
		title: _propTypes2.default.string,
		bsStyle: _propTypes2.default.string
	}),

	// input
	autoFocus: _propTypes2.default.bool,
	debounceMinLength: _propTypes2.default.number,
	debounceTimeout: _propTypes2.default.number,
	onBlur: _propTypes2.default.func,
	onChange: _propTypes2.default.func,
	onFocus: _propTypes2.default.func,
	placeholder: _propTypes2.default.string,
	value: _propTypes2.default.string,

	// suggestions
	onSelect: _propTypes2.default.func,
	onKeyDown: _propTypes2.default.func,
	focusedSectionIndex: _propTypes2.default.number,
	focusedItemIndex: _propTypes2.default.number,
	multiSection: _propTypes2.default.bool,
	items: _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.shape({
		title: _propTypes2.default.string,
		description: _propTypes2.default.string,
		suggestions: _propTypes2.default.arrayOf(_propTypes2.default.shape({
			title: _propTypes2.default.string,
			description: _propTypes2.default.string
		}))
	})]))
};

exports.default = Typeahead;